@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-auth
-version: 1.4.13
-id: yesod-auth-1.4.13-afc8684a8e9e9b053e698b268da75a0d
-key: yesod_8AYO1DkBCVWBhjD9i50tRc
+version: 1.4.13.2
+id: yesod-auth-1.4.13.2-e638e081132a85618f37f43080bc4eb4
+key: yesod_1AbRBQZZLwxL7hUDre699C
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -20,51 +20,51 @@ exposed-modules:
     Yesod.Auth.GoogleEmail Yesod.Auth.GoogleEmail2 Yesod.Auth.Hardcoded
 hidden-modules: Yesod.Auth.Routes Yesod.PasswordStore
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.13
-library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.13
-data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-auth-1.4.13
-hs-libraries: HSyesod-auth-1.4.13-8AYO1DkBCVWBhjD9i50tRc
+import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.13.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-auth-1.4.13.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-auth-1.4.13.2
+hs-libraries: HSyesod-auth-1.4.13.2-1AbRBQZZLwxL7hUDre699C
 depends:
-    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
-    authenticate-1.3.3-8786f6078b464d3c3f52185ef882a223
+    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
+    authenticate-1.3.3.1-d5d29d33a55e5a55915307e270a92892
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
-    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
-    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
+    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
+    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
+    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.12.1-34a75d65f1bcf0a6ace65de178beb2df
+    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
+    conduit-extra-1.1.13.1-eddf025ec4463f8bba96cb21182c4b0f
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cryptohash-0.11.9-66ecf9651f97183101697edd4149971c
-    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
-    email-validate-2.2.0-2cb19fcad74f009f580f5d1a0c1a07e6
-    file-embed-0.0.9.1-490f794ac7ce2cc242aa3be8fec9767e
-    http-client-0.4.27-1cd31210c8ec4a6e0b4cc467bd24f592
-    http-conduit-2.1.8-0cd87eafc953cbe4f675bdf50a2df8e2
-    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
-    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
-    mime-mail-0.4.11-363f204ae632de52ba204fa0d2f16891
+    cryptohash-0.11.9-1ce6a3e7b661f39b36d188b8c49a9b44
+    data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
+    email-validate-2.2.0-b56e57eb2689ad2a5bb9495f35baa8f4
+    file-embed-0.0.10-c7da10dfba0f55c7c135317c0bfb8508
+    http-client-0.4.28-bc84c1de0ba23b26cbd36cc941948a7e
+    http-conduit-2.1.10.1-25cf7e0ab425a3f9a6e4adec2d684722
+    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
+    lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
+    mime-mail-0.4.11-d9015aaaa236b99cae24cbb7fe985a3e
     network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
-    nonce-1.0.2-c0bfd19efc8c42e1c2c83d3a058f813a
-    persistent-2.2.4.1-f7f5136d623755022a88522f150cf471
-    persistent-template-2.1.6-696af2309e8b2b7d269b843dd09030c3
+    nonce-1.0.2-4d1212dfb084a803f723eea311d0a719
+    persistent-2.2.4.1-d8d907c8c62628a6667ab3fa39fc892f
+    persistent-template-2.1.6-83163c252d18f4a1e745e383b4fcf281
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
     safe-0.3.9-b613242f536083d5bb04920ede356aea
-    shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
+    shakespeare-2.0.8.2-ff3f7104513a25f68869f5890fce9d82
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
-    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
-    yesod-core-1.4.20-a64b314810952b5a1be9638e42c84862
-    yesod-form-1.4.7-65d4c1c67a98e3c400d577cc5e8a906b
-    yesod-persistent-1.4.0.4-a374b45e8b618c21d99c5a049b52b954
+    wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
+    yesod-core-1.4.20.2-aced7b6b1008af0f1a8e5e3876fc55af
+    yesod-form-1.4.7.1-5d1acfd5ba57bcb9acd30a4f556f6cdd
+    yesod-persistent-1.4.0.5-a3f7b6a3b9261de48209b70a4cc548df
 haddock-interfaces: /usr/share/doc/haskell-yesod-auth/html/yesod-auth.haddock
 haddock-html: /usr/share/doc/haskell-yesod-auth/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
